{% extends 'djiki/base_page.html' %} {% load i18n djiki_tags %} {% load url from future %} {% block title %}{% trans "Page history" %}: {{ block.super }}{% endblock %} {% block djiki_main %}

# {{ page.title }}

{% trans "Modification time" %} |  | {% trans "Author" %} | {% trans "Description" %} | {% trans "Operations" %}
--- | --- | --- | --- | ---
{% for revision in history %}
{{ revision.created }} ({% blocktrans with revision.created|timesince as timesince %}{{ timesince }} ago{% endblocktrans %}) |  | {% if revision.author %}{{ revision.author }} {% else %}{% trans "anonymous" %}{% endif %} | {{ revision.description }} | [{% trans "revert" %}] [{% trans "undo" %}]
{% endfor %}

{% endblock %}